# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.projects import projects_pb2 as qwak_dot_projects_dot_projects__pb2


class ProjectsManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateProject = channel.unary_unary(
                '/qwak.projects.management.ProjectsManagementService/CreateProject',
                request_serializer=qwak_dot_projects_dot_projects__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=qwak_dot_projects_dot_projects__pb2.CreateProjectResponse.FromString,
                )
        self.ListProjects = channel.unary_unary(
                '/qwak.projects.management.ProjectsManagementService/ListProjects',
                request_serializer=qwak_dot_projects_dot_projects__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=qwak_dot_projects_dot_projects__pb2.ListProjectsResponse.FromString,
                )
        self.GetProject = channel.unary_unary(
                '/qwak.projects.management.ProjectsManagementService/GetProject',
                request_serializer=qwak_dot_projects_dot_projects__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=qwak_dot_projects_dot_projects__pb2.GetProjectResponse.FromString,
                )
        self.DeleteProject = channel.unary_unary(
                '/qwak.projects.management.ProjectsManagementService/DeleteProject',
                request_serializer=qwak_dot_projects_dot_projects__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=qwak_dot_projects_dot_projects__pb2.DeleteProjectResponse.FromString,
                )
        self.UpdateProject = channel.unary_unary(
                '/qwak.projects.management.ProjectsManagementService/UpdateProject',
                request_serializer=qwak_dot_projects_dot_projects__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=qwak_dot_projects_dot_projects__pb2.UpdateProjectResponse.FromString,
                )


class ProjectsManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateProject(self, request, context):
        """Create project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProjects(self, request, context):
        """List all projects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProject(self, request, context):
        """Get project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProject(self, request, context):
        """Delete project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProject(self, request, context):
        """Update project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectsManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProject,
                    request_deserializer=qwak_dot_projects_dot_projects__pb2.CreateProjectRequest.FromString,
                    response_serializer=qwak_dot_projects_dot_projects__pb2.CreateProjectResponse.SerializeToString,
            ),
            'ListProjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjects,
                    request_deserializer=qwak_dot_projects_dot_projects__pb2.ListProjectsRequest.FromString,
                    response_serializer=qwak_dot_projects_dot_projects__pb2.ListProjectsResponse.SerializeToString,
            ),
            'GetProject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProject,
                    request_deserializer=qwak_dot_projects_dot_projects__pb2.GetProjectRequest.FromString,
                    response_serializer=qwak_dot_projects_dot_projects__pb2.GetProjectResponse.SerializeToString,
            ),
            'DeleteProject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProject,
                    request_deserializer=qwak_dot_projects_dot_projects__pb2.DeleteProjectRequest.FromString,
                    response_serializer=qwak_dot_projects_dot_projects__pb2.DeleteProjectResponse.SerializeToString,
            ),
            'UpdateProject': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProject,
                    request_deserializer=qwak_dot_projects_dot_projects__pb2.UpdateProjectRequest.FromString,
                    response_serializer=qwak_dot_projects_dot_projects__pb2.UpdateProjectResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.projects.management.ProjectsManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectsManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.projects.management.ProjectsManagementService/CreateProject',
            qwak_dot_projects_dot_projects__pb2.CreateProjectRequest.SerializeToString,
            qwak_dot_projects_dot_projects__pb2.CreateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.projects.management.ProjectsManagementService/ListProjects',
            qwak_dot_projects_dot_projects__pb2.ListProjectsRequest.SerializeToString,
            qwak_dot_projects_dot_projects__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.projects.management.ProjectsManagementService/GetProject',
            qwak_dot_projects_dot_projects__pb2.GetProjectRequest.SerializeToString,
            qwak_dot_projects_dot_projects__pb2.GetProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.projects.management.ProjectsManagementService/DeleteProject',
            qwak_dot_projects_dot_projects__pb2.DeleteProjectRequest.SerializeToString,
            qwak_dot_projects_dot_projects__pb2.DeleteProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.projects.management.ProjectsManagementService/UpdateProject',
            qwak_dot_projects_dot_projects__pb2.UpdateProjectRequest.SerializeToString,
            qwak_dot_projects_dot_projects__pb2.UpdateProjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
